@@ -154,7 +154,7 @@ void KSMainWindow::init()
     mDialogButtonBox->button(QDialogButtonBox::Help)->setMenu(helpMenu->menu());
 
     // message widget
-    connect(mMessageWidget, &KMessageWidget::linkActivated, &QDesktopServices::openUrl);
+    connect(mMessageWidget, &KMessageWidget::linkActivated, this, [](const QString &str) { QDesktopServices::openUrl(QUrl(str)); } );
 
     // layouts
 
@@ -328,6 +328,7 @@ void KSMainWindow::saveAs()
 void KSMainWindow::saveAndExit()
 {
     SpectacleConfig::instance()->setLastUsedSaveMode(0);
-    ExportManager::instance()->doSave();
-    QApplication::quit();
+    qApp->setQuitOnLastWindowClosed(false);
+    ExportManager::instance()->doSave(QUrl(), true);
+    hide();
 }
